---
title: Features
description: 'All the features this module offers for building apps with Ionic at great speed'
---

## Page routing

Out of the box, you can start building your Ionic application by creating routes within `~/pages` directory. To access the router, you should use `useIonRouter()` rather than `useRouter()` (which is auto-imported from `vue-router`).

Nuxt utilities like `definePageMeta` will continue to work, but you should avoid using `<NuxtPage>` or `<NuxtLayout>`.

::alert
The root component of every page should be the `<ion-page>` component.
::

::alert
If you do not have a `~/pages/index.vue` file in your project, you should add the following code to the page that you want to be displayed on your app's root page:

```ts [pages/home.vue]
definePageMeta({
  alias: ['/'],
})
```

::

## Components

All Ionic Vue components should be auto-imported throughout your app. (If you find one that isn't, please open an issue.) Although your IDE should be aware of these everywhere, they are not globally registered and are only imported within the components that use them.

For more on how component imports work, see the [Nuxt documentation](https://v3.nuxtjs.org/guide/directory-structure/components#components-directory).

## Icons

Icons are auto-imported from `ionicons/icons` by default, following the pattern of camel case naming with `ionicons` in front of the original icon name from the [official icons website](https://ionic.io/ionicons).

For example, instead of this

```vue [component.vue]
<script setup lang="ts">
import { image, squareSharp, triangleOutline } from 'ionicons/icons'
</script>

<template>
  <ion-icon :icon="image"></ion-icon>
  <ion-icon :md="squareSharp" :ios="triangleOutline"></ion-icon>
</template>
```

You would write this

```vue [component.vue]
<template>
  <ion-icon :icon="ioniconsImage"></ion-icon>
  <ion-icon :md="ioniconsSquareSharp" :ios="ioniconsTriangleOutline"></ion-icon>
</template>
```

You can opt-out of auto-importing by setting `integrations.icons` module options in your `nuxt.config.ts` to `false`.

## Helper functions

Nuxt provides a number of Ionic hooks/composables via auto-imports within your app:

`createAnimation`, `createGesture`, `getPlatforms`, `getTimeGivenProgression`, `iosTransitionAnimation`, `isPlatform`, `mdTransitionAnimation`, `menuController`, `onIonViewWillEnter`, `onIonViewDidEnter`, `onIonViewWillLeave`, `onIonViewDidLeave`, `useBackButton`, `useKeyboard`, `useIonRouter`

For more on what these do, you can read the [Ionic docs](https://ionicframework.com/docs/). For more on how auto-imports work, see the [Nuxt documentation](https://v3.nuxtjs.org/guide/concepts/auto-imports#auto-imports).

## Advanced

### Customizing your root `app.vue`

If you need to customize the default Ionic `app.vue` file, you can create a new one in your project's source directory.

This is the default:

```vue [app.vue]
<template>
  <ion-app>
    <ion-router-outlet />
  </ion-app>
</template>
```
